@@ -27,7 +27,7 @@
  *
  */
 
-#define	VersionCH	"1.6.8"
+#define	VersionCH	"1.7.3"
 
 extern int CommCheck(int fdser, int yAddress);
 extern int GetState(int fdser, int yAddress);
@@ -41,11 +41,13 @@ extern int GetDSP(int fdser, int yAddress);
 extern int GetDSPExtended(int fdser, int yAddress);
 extern int GetDSP3Phase(int fdser, int yAddress);
 extern int GetCE(int fdser, int yAddress);
+extern int GetCESent(int fdser, int yAddress, int yGetEnergySent);
 extern int GetCEDaily(int fdser, int yAddress, int yGetEnergyDaily);
 extern int GetJoules(int fdser, int yAddress);
 extern int GetCounters(int fdser, int yAddress);
 extern int GetTime(int fdser, int yAddress);
-extern int SetTime(int fdser, int yAddress);
+extern int SetTime(int fdser, int yAddress, BOOL force);
+extern int CheckSetTime(int fdser, int yAddress);
 extern int GetLastAlarms(int fdser, int yAddress);
 
 extern char     VersionC[];
