@@ -27,7 +27,7 @@
  *
  */
 
-#define	VersionNH	"1.6.8"
+#define	VersionNH	"1.7.2"
 
 /* # 50 State Request */
 
@@ -245,6 +245,14 @@
 #define aRel1   4
 #define aRel0   5
 
+/* # 75 Energy delivred to grip every 10 seconds ** Experimental ** */
+
+#define opGetCESent	0x4b01  /* 75 01 */
+#define _opGetCESent "Energy Sent To Grid"
+
+#define aCESMemAdd	0x000a
+#define aCESMaxCnt	4320
+
 /* # 75 Energy cumulated each day address ** Experimental ** */
 
 #define opGetCEAdd	0x4b02	/* 75 02 */
@@ -301,8 +309,8 @@
 
 /* # 79 Daily Cumulated Energy ** Experimental ** */
 
-#define opGetCEDaily	79
-#define _opGetCEDaily "Daily Cumulated Energy"
+#define opGetCEValue	79
+#define _opGetCEValue "Cumulated Energy"
 
 #define cCEDailyAddH	2
 #define cCEDailyAddL	3
